@@ -1,19 +1,19 @@
 # coding=utf-8
 
-from typing import List, get_type_hints
 import inspect
-from functools import partial
 from abc import ABCMeta, abstractmethod
+from functools import partial
+from typing import List, get_type_hints
 
-from guniflask.beans.post_processor import BeanPostProcessor
+from guniflask.beans.constructor_resolver import ConstructorResolver
 from guniflask.beans.definition import BeanDefinition
 from guniflask.beans.definition_registry import BeanDefinitionRegistry
 from guniflask.beans.errors import BeanTypeNotDeclaredError, BeanTypeNotAllowedError, BeanCreationError, \
     BeanNotOfRequiredTypeError, NoUniqueBeanDefinitionError
-from guniflask.beans.lifecycle import InitializingBean, SmartInitializingSingleton, DisposableBean
-from guniflask.beans.constructor_resolver import ConstructorResolver
-from guniflask.beans.factory import BeanFactoryAware, BeanNameAware, ConfigurableBeanFactory
 from guniflask.beans.errors import NoSuchBeanDefinitionError, BeanDefinitionStoreError
+from guniflask.beans.factory import BeanFactoryAware, BeanNameAware, ConfigurableBeanFactory
+from guniflask.beans.lifecycle import InitializingBean, SmartInitializingSingleton, DisposableBean
+from guniflask.beans.post_processor import BeanPostProcessor
 
 
 class AbstractBeanFactory(ConfigurableBeanFactory, metaclass=ABCMeta):
@@ -41,11 +41,13 @@ class AbstractBeanFactory(ConfigurableBeanFactory, metaclass=ABCMeta):
         else:
             bean_definition = self.get_bean_definition(bean_name)
             if bean_definition.is_singleton():
-                bean = self.get_singleton_from_factory(bean_name,
-                                                       partial(self.create_bean, bean_name, bean_definition))
+                bean = self.get_singleton_from_factory(
+                    bean_name,
+                    partial(self.create_bean, bean_name, bean_definition),
+                )
             elif bean_definition.is_prototype():
-                # TODO: support prototype
-                pass
+                # FIXME: support prototype
+                raise RuntimeError('Do not support prototype now')
 
         # Check if required type matches the type of the actual bean instance.
         if bean is not None and required_type is not None:
@@ -94,15 +96,15 @@ class AbstractBeanFactory(ConfigurableBeanFactory, metaclass=ABCMeta):
 
     @abstractmethod
     def create_bean(self, bean_name: str, bean_definition: BeanDefinition):
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def contains_bean_definition(self, bean_name: str) -> bool:
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def get_bean_definition(self, bean_name: str) -> BeanDefinition:
-        pass
+        pass  # pragma: no cover
 
 
 class DefaultBeanFactory(AbstractBeanFactory, BeanDefinitionRegistry):
