@@ -1,7 +1,7 @@
 # coding=utf-8
 
-from typing import List
 from abc import ABCMeta, abstractmethod
+from typing import List
 
 from guniflask.beans.definition import BeanDefinition
 
@@ -10,20 +10,20 @@ class BeanDefinitionRegistry(metaclass=ABCMeta):
 
     @abstractmethod
     def register_bean_definition(self, bean_name: str, bean_definition: BeanDefinition):
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def get_bean_definition(self, bean_name: str) -> BeanDefinition:
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def get_bean_definition_names(self) -> List[str]:
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def contains_bean_definition(self, bean_name: str) -> bool:
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def remove_bean_definition(self, bean_name: str):
-        pass
+        pass  # pragma: no cover
