@@ -6,16 +6,16 @@ from abc import ABCMeta, abstractmethod
 class InitializingBean(metaclass=ABCMeta):
     @abstractmethod
     def after_properties_set(self):
-        pass
+        pass  # pragma: no cover
 
 
 class SmartInitializingSingleton(metaclass=ABCMeta):
     @abstractmethod
     def after_singletons_instantiated(self):
-        pass
+        pass  # pragma: no cover
 
 
 class DisposableBean(metaclass=ABCMeta):
     @abstractmethod
     def destroy(self):
-        pass
+        pass  # pragma: no cover
