@@ -4,8 +4,8 @@ import inspect
 from typing import Type, Collection, Union, Any
 
 from guniflask.annotation import Annotation, AnnotationUtils, AnnotationMetadata
+from guniflask.config.app_settings import settings
 from guniflask.context.condition import Condition, ConditionContext
-from guniflask.config import settings
 
 
 class Bean(Annotation):
