@@ -3,8 +3,8 @@
 from abc import ABCMeta, abstractmethod
 
 from guniflask.annotation import AnnotationMetadata
-from guniflask.beans.factory import BeanFactory
 from guniflask.beans.definition_registry import BeanDefinitionRegistry
+from guniflask.beans.factory import BeanFactory
 
 
 class ConditionContext:
@@ -19,4 +19,4 @@ class ConditionContext:
 class Condition(metaclass=ABCMeta):
     @abstractmethod
     def matches(self, context: ConditionContext, metadata: AnnotationMetadata) -> bool:
-        pass
+        pass  # pragma: no cover
