@@ -1,12 +1,12 @@
 # coding=utf-8
 
+import fcntl
+import getpass
 import os
 import tempfile
 from os.path import join, exists
-import fcntl
-import getpass
 
-from guniflask.config.app_config import settings
+from guniflask.config.app_settings import settings
 
 
 class ServiceLock:
@@ -35,7 +35,7 @@ class ServiceLock:
         return True
 
     def _generate_instance_id(self) -> str:
-        return f'{settings["project_name"]}.{settings["port"]}.lock'
+        return f'{settings["app_name"]}.{settings["port"]}.lock'
 
     def release(self):
         instance_id = self._generate_instance_id()
