@@ -3,6 +3,7 @@
 from abc import ABCMeta, abstractmethod
 
 from apscheduler.schedulers.background import BackgroundScheduler
+
 from guniflask.beans.lifecycle import DisposableBean, SmartInitializingSingleton
 
 
@@ -10,7 +11,7 @@ class AsyncExecutor(metaclass=ABCMeta):
 
     @abstractmethod
     def submit(self, task):
-        pass
+        pass  # pragma: no cover
 
 
 class DefaultAsyncExecutor(AsyncExecutor, SmartInitializingSingleton, DisposableBean):
