@@ -1,27 +1,28 @@
 # coding=utf-8
 
-from abc import ABCMeta, abstractmethod
 import datetime as dt
+from abc import ABCMeta, abstractmethod
 
 from apscheduler.schedulers.background import BackgroundScheduler
 from apscheduler.triggers.cron import CronTrigger
 from apscheduler.triggers.date import DateTrigger
 from apscheduler.triggers.interval import IntervalTrigger
+
 from guniflask.beans.lifecycle import SmartInitializingSingleton, DisposableBean
 
 
 class TaskScheduler(metaclass=ABCMeta):
     @abstractmethod
     def schedule(self, task, start_time: dt.datetime = None):
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def schedule_with_cron(self, task, cron: str, start_time: dt.datetime = None):
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def schedule_with_fixed_interval(self, task, interval: int, start_time: dt.datetime = None):
-        pass
+        pass  # pragma: no cover
 
 
 class DefaultTaskScheduler(TaskScheduler, SmartInitializingSingleton, DisposableBean):
