@@ -8,4 +8,4 @@ from guniflask.security.authentication import Authentication
 class AuthenticationManager(metaclass=ABCMeta):
     @abstractmethod
     def authenticate(self, authentication: Authentication) -> Authentication:
-        pass
+        pass  # pragma: no cover
