@@ -9,4 +9,4 @@ from guniflask.security.user_details import UserDetails
 class AuthenticationUserDetailsService(metaclass=ABCMeta):
     @abstractmethod
     def load_user_details(self, token: Authentication) -> UserDetails:
-        pass
+        pass  # pragma: no cover
