@@ -1,8 +1,8 @@
 # coding=utf-8
 
+import inspect
 from abc import ABCMeta, abstractmethod
 from typing import Type
-import inspect
 
 from guniflask.security.authentication import Authentication
 from guniflask.security.authentication_provider import AuthenticationProvider
@@ -14,11 +14,11 @@ class UserDetailsAuthenticationProvider(AuthenticationProvider, metaclass=ABCMet
 
     @abstractmethod
     def retrieve_user(self, username: str, authentication: UserAuthentication) -> UserDetails:
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def check_authentication(self, user_details: UserDetails, authentication: UserAuthentication):
-        pass
+        pass  # pragma: no cover
 
     def authenticate(self, authentication: Authentication):
         assert isinstance(authentication, UserAuthentication)
