@@ -3,5 +3,5 @@
 from .config import ServiceDiscoveryConfigurer
 from .discovery_client import DiscoveryClient
 from .load_balancer_client import LoadBalancerClient
-from .load_balancer_client import LoadBalancedRequest
+from .load_balancer_client import RestClient
 from .service_instance import ServiceInstance
