@@ -2,8 +2,8 @@
 
 from flask import abort
 
+from guniflask.config.app_settings import settings
 from guniflask.web.bind_annotation import blueprint, get_route
-from guniflask.config.app_config import settings
 
 
 @blueprint
@@ -20,7 +20,7 @@ class HealthEndpoint:
         return self.health_check()
 
     def _check_info(self, name: str, active_profile: str):
-        if name != settings['project_name']:
+        if name != settings['app_name']:
             return False
 
         if not active_profile:
