@@ -12,14 +12,14 @@ class LoadBalancerClient(metaclass=ABCMeta):
 
     @abstractmethod
     def choose(self, service_name: str) -> ServiceInstance:
-        pass
+        pass  # pragma: no cover
 
     @abstractmethod
     def reconstruct_url(self, service_instance: ServiceInstance, original_url: str) -> str:
-        pass
+        pass  # pragma: no cover
 
 
-class LoadBalancedRequest(Session):
+class RestClient(Session):
 
     def __init__(self, load_balancer_client: LoadBalancerClient):
         assert load_balancer_client is not None, 'LoadBalancerClient is required'
