@@ -65,20 +65,3 @@ def patch_route(rule: str = None, **options):
 def delete_route(rule: str = None, **options):
     options['methods'] = ['DELETE']
     return route(rule=rule, **options)
-
-
-class WebSocket(Annotation):
-    def __init__(self, rule: str = None):
-        super().__init__(rule=rule)
-
-
-def websocket(rule: str = None):
-    def wrap_func(func):
-        AnnotationUtils.add_annotation(func, WebSocket(rule=rule))
-        return func
-
-    if inspect.isfunction(rule) or inspect.isclass(rule):
-        f = rule
-        rule = None
-        return wrap_func(f)
-    return wrap_func
