@@ -1,25 +1,22 @@
 # coding=utf-8
 
-from functools import update_wrapper
 import inspect
+from functools import update_wrapper
 
 from flask import Blueprint as FlaskBlueprint, request, current_app
 from werkzeug.exceptions import BadRequest, InternalServerError
 from werkzeug.routing import parse_rule
-from starlette.websockets import WebSocketDisconnect
 
 from guniflask.annotation import AnnotationUtils
 from guniflask.beans.post_processor import BeanPostProcessor
-from guniflask.web.bind_annotation import Blueprint, Route, WebSocket
-from guniflask.utils.inspect import inspect_args
-from guniflask.utils.request import map_object
+from guniflask.context.event import ContextRefreshedEvent, ApplicationEvent
+from guniflask.context.event_listener import ApplicationEventListener
+from guniflask.data_model.mapping import map_json, inspect_args, resolve_arg_type, ArgType
+from guniflask.web import param_annotation
+from guniflask.web.bind_annotation import Blueprint, Route
+from guniflask.web.filter_annotation import MethodDefFilter
 from guniflask.web.param_annotation import FieldInfo, RequestParam, PathVariable, RequestParamInfo, PathVariableInfo, \
     RequestBodyInfo, FilePartInfo, FormValueInfo, RequestHeaderInfo, CookieValueInfo, RequestBody
-from guniflask.web import param_annotation
-from guniflask.context.event_listener import ApplicationEventListener
-from guniflask.context.event import ContextRefreshedEvent, ApplicationEvent
-from guniflask.web.filter_annotation import MethodDefFilter
-from guniflask.utils.inspect import resolve_arg_type, ArgType
 
 
 class BlueprintPostProcessor(BeanPostProcessor, ApplicationEventListener):
@@ -41,7 +38,6 @@ class BlueprintPostProcessor(BeanPostProcessor, ApplicationEventListener):
             for m in dir(bean):
                 method = getattr(bean, m)
                 self._resolve_route(b, method)
-                self._resolve_websocket_route(b, method)
                 self._resolve_method_def_filter(b, method)
             self.blueprints.append(b)
         return bean
@@ -66,26 +62,6 @@ class BlueprintPostProcessor(BeanPostProcessor, ApplicationEventListener):
 
         return update_wrapper(wrapper, method)
 
-    def _resolve_websocket_route(self, blueprint: FlaskBlueprint, method):
-        a = AnnotationUtils.get_annotation(method, WebSocket)
-        if a is not None:
-            rule = a['rule'] or '/'
-            rule_prefix = blueprint.url_prefix or '/'
-            rule = '/'.join((rule_prefix.rstrip('/'), rule.lstrip('/')))
-            current_app.asgi_app.add_websocket_route(rule, self._wrap_websocket_func(method))
-
-    def _wrap_websocket_func(self, method):
-        app = current_app._get_current_object()
-
-        async def wrapper(*args, **kwargs):
-            with app.app_context():
-                try:
-                    return await method(*args, **kwargs)
-                except WebSocketDisconnect:
-                    pass
-
-        return update_wrapper(wrapper, method)
-
     def _resolve_method_def_filter(self, blueprint, method):
         a = AnnotationUtils.get_annotation(method, MethodDefFilter)
         if a is None:
@@ -200,7 +176,7 @@ class BlueprintPostProcessor(BeanPostProcessor, ApplicationEventListener):
                         result[k] = v
             elif isinstance(p, RequestBodyInfo):
                 data = request.json
-                v = map_object(data, dtype=p.dtype)
+                v = map_json(data, dtype=p.dtype)
                 if v is not None:
                     result[k] = v
             elif isinstance(p, FilePartInfo):
